Data science gear (ds-gear) is a Python API for advanced machine learning algorithms built on top of sklearn, tensorflow and keras and is distributed under the Mit license.
### Installation
## Depenencies
- Python (> 3.6)
- Numpy (> 1.19)
- Pandas (> 1.0.4)
- sklearn (>0.23)
- Matplotlib
- Pylint
- Doxypypy
- Nltk (==3.5)
- keras (v 2.3.1)
- tensorflow (v 2.2.0)
## User installation
pip install ds-gear

### Source code
You can check the latest sources with the command:
git clone https://github.com/AI-Companion/ds-gear.git
